==> kubernetes-model-gatewayapi-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPPathModifierFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPPathModifierFluent<A extends HTTPPathModifierFluent<A>> extends BaseFluent<A>{
  public HTTPPathModifierFluent() {
  }
  public HTTPPathModifierFluent(HTTPPathModifier instance) {
    instance = (instance != null ? instance : new HTTPPathModifier());

    if (instance != null) {
      this.withReplaceFullPath(instance.getReplaceFullPath());
      this.withReplacePrefixMatch(instance.getReplacePrefixMatch());
      this.withType(instance.getType());
      this.withReplaceFullPath(instance.getReplaceFullPath());
      this.withReplacePrefixMatch(instance.getReplacePrefixMatch());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String replaceFullPath;
  private String replacePrefixMatch;
  private String type;
  private Map<String,Object> additionalProperties;
  public String getReplaceFullPath() {
    return this.replaceFullPath;
  }
  public A withReplaceFullPath(String replaceFullPath) {
    this.replaceFullPath=replaceFullPath; return (A) this;
  }
  public boolean hasReplaceFullPath() {
    return this.replaceFullPath != null;
  }
  public String getReplacePrefixMatch() {
    return this.replacePrefixMatch;
  }
  public A withReplacePrefixMatch(String replacePrefixMatch) {
    this.replacePrefixMatch=replacePrefixMatch; return (A) this;
  }
  public boolean hasReplacePrefixMatch() {
    return this.replacePrefixMatch != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPPathModifierFluent that = (HTTPPathModifierFluent) o;
    if (!java.util.Objects.equals(replaceFullPath, that.replaceFullPath)) return false;

    if (!java.util.Objects.equals(replacePrefixMatch, that.replacePrefixMatch)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(replaceFullPath,  replacePrefixMatch,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (replaceFullPath != null) { sb.append("replaceFullPath:"); sb.append(replaceFullPath + ","); }
    if (replacePrefixMatch != null) { sb.append("replacePrefixMatch:"); sb.append(replacePrefixMatch + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-gatewayapi-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPPathModifierFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPPathModifierFluent<A extends HTTPPathModifierFluent<A>> extends BaseFluent<A>{
  public HTTPPathModifierFluent() {
  }
  
  public HTTPPathModifierFluent(HTTPPathModifier instance) {
    this.copyInstance(instance);
  }
  private String replaceFullPath;
  private String replacePrefixMatch;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HTTPPathModifier instance) {
    instance = (instance != null ? instance : new HTTPPathModifier());
  
    if (instance != null) {
        this.withReplaceFullPath(instance.getReplaceFullPath());
        this.withReplacePrefixMatch(instance.getReplacePrefixMatch());
        this.withType(instance.getType());
        this.withReplaceFullPath(instance.getReplaceFullPath());
        this.withReplacePrefixMatch(instance.getReplacePrefixMatch());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getReplaceFullPath() {
    return this.replaceFullPath;
  }
  
  public A withReplaceFullPath(String replaceFullPath) {
    this.replaceFullPath=replaceFullPath; return (A) this;
  }
  
  public boolean hasReplaceFullPath() {
    return this.replaceFullPath != null;
  }
  
  public String getReplacePrefixMatch() {
    return this.replacePrefixMatch;
  }
  
  public A withReplacePrefixMatch(String replacePrefixMatch) {
    this.replacePrefixMatch=replacePrefixMatch; return (A) this;
  }
  
  public boolean hasReplacePrefixMatch() {
    return this.replacePrefixMatch != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPPathModifierFluent that = (HTTPPathModifierFluent) o;
    if (!java.util.Objects.equals(replaceFullPath, that.replaceFullPath)) return false;
  
    if (!java.util.Objects.equals(replacePrefixMatch, that.replacePrefixMatch)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(replaceFullPath,  replacePrefixMatch,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (replaceFullPath != null) { sb.append("replaceFullPath:"); sb.append(replaceFullPath + ","); }
    if (replacePrefixMatch != null) { sb.append("replacePrefixMatch:"); sb.append(replacePrefixMatch + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
